Learn R Programming

sensitivityCalibration (version 0.0.1)

NHANES_blood_lead_small: A random subset of NHANES_blood_lead data.

Description

A random subset of NHANES_blood_lead data for the purpose of testing.

Usage

data(NHANES_blood_lead_small)

Arguments

Format

A random sample from the NHANES_blood_lead dataset. It consists of 500 instances and the same 10 variables as the NHANES_blood_lead data.

COP

treatment, 1 if cotinine level is between 0.563-14.9 ng/ml and 0 otherwise

DMARETHN

1 if white, 0 if others

DMPPIR

Poverty income ratio

HFE1

1 if the house is built before 1974, 0 if after 1974

HFE2

number of rooms in the house

HFHEDUCR

education level of the reference adult

HSAGEIR

age at the time of interview

HSFSIZER

size of the family

HSSEX

1 if male, 0 if female

PBP

blood lead level

Details

We take a 500 random sample from the NHANES_blood_lead dataset. This small dataset is primarily for the purpose of testing the algorithm.

References

D. M. Mannino, R. Albalak, S. D. Grosse, and J. Repace. Second-hand smoke exposureand blood lead levels in U.S. children.Epidemiology, 14:719-727, 2003

A. Gelman. Scaling regression inputs by dividing by two standard deviations.Statisticsin Medicine, 27:2865-2873, 2008.

Examples

Run this code
# NOT RUN {
data(NHANES_blood_lead_small)
# }

Run the code above in your browser using DataLab